@@ -1,15 +1,16 @@
 # coding=utf-8
-__version__ = "6.0.59"
-
-import sys
+__version__ = "6.1.27"
 
 from zuper_commons.logs import ZLogger
 
 logger = ZLogger(__name__)
 
-enc = sys.getdefaultencoding()
+import os
 
-logger.info(f"{__version__}")
+path = os.path.dirname(os.path.dirname(__file__))
+
+
+logger.debug(f"duckietown_challenges_runner version {__version__} path {path}")
 from .runner import dt_challenges_evaluator
 
 from .runner_local import runner_local_main
